---
title: <span class="badge object-type-scalar"></span> Timeticks
---
# <span class="badge object-type-scalar"></span> Timeticks

Time: Timeticks (s/100)

## Definition

```python
# Time: Timeticks (s/100)
Timeticks: typing.Literal["timeticks"] = "timeticks"
```
